@@ -37,7 +37,7 @@ from .extensions import CameraSkybellControllerExtension
 from .extensions import ConfigurationOption
 from .extensions import ExtendedProperties
 
-__version__ = "0.4.3"
+__version__ = "0.4.4"
 
 
 log = logging.getLogger(__name__)
@@ -789,7 +789,8 @@ class AlarmController:
             ) as resp:
                 json_rsp = await resp.json()
 
-                log.debug("Got identity info:\n%s", json.dumps(json_rsp))
+                # This is a verbose response. Uncommend when needed.
+                # log.debug("Got identity info:\n%s", json.dumps(json_rsp))
 
                 self._user_id = json_rsp["data"][0]["id"]
                 self._provider_name = json_rsp["data"][0]["attributes"]["logoName"]
